from setuptools import setup, find_packages

setup(
    name="patal",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[
        "numpy",
        "numba",
    ],
    author="Your Name",
    author_email="your.email@example.com",
    description="A simple CUDA-enabled Python library",
    keywords="cuda, gpu, parallel computing",
) 